@@ -21,8 +21,13 @@ Dependencies:
 Config:
     channels ((str, str list) dict):
         Mapping from virtual channel names to lists of channel names to bridge.
+    plugs ((str, dict) dict):
+        Mapping from plug names to plug-specific config.  This allows overriding the following
+        top-level config values: joins, renames, reset-author, name-format, strip-name-emoji
     plug (str):
         Name of a virtual plug to register for this sync.
+    edits (bool):
+        Whether to sync updates to, and deletions of, messages across the bridge.
     joins (bool):
         Whether to sync join and part messages across the bridge.
     renames (bool):
@@ -79,6 +84,9 @@ Requirements:
 Config:
     channels ((str, str list) dict):
         Mapping from source channel names to lists of channel names to forward to.
+    plugs ((str, dict) dict):
+        Mapping from plug names to plug-specific config.  This allows overriding the following
+        top-level config values: joins, renames, reset-author, name-format, strip-name-emoji
     users (str list):
         Whitelist of user IDs to accept source messages from.  If set, messages from anyone else in
         the source channel will be ignored.
@@ -477,7 +485,14 @@ class SyncPlug(immp.Plug):
 
 class _SyncHookBase(immp.Hook):
 
+    _override_config = {immp.Optional("joins", immp.Optional.MISSING): bool,
+                        immp.Optional("renames", immp.Optional.MISSING): bool,
+                        immp.Optional("reset-author", immp.Optional.MISSING): bool,
+                        immp.Optional("name-format", immp.Optional.MISSING): immp.Nullable(str),
+                        immp.Optional("strip-name-emoji", immp.Optional.MISSING): bool}
+
     schema = immp.Schema({"channels": {str: [str]},
+                          immp.Optional("plugs", dict): {str: _override_config},
                           immp.Optional("joins", False): bool,
                           immp.Optional("renames", False): bool,
                           immp.Optional("identities"): immp.Nullable(str),
@@ -487,11 +502,20 @@ class _SyncHookBase(immp.Hook):
 
     _identities = immp.ConfigProperty(IdentityProvider)
 
+    def _plug_config(self, channel):
+        keys = tuple(immp.Optional.unwrap(key)[0] for key in self._override_config)
+        config = {key: self.config[key] for key in keys}
+        if channel and channel.plug:
+            override = self.config["plugs"].get(channel.plug.name) or {}
+            config.update({key: override[key] for key in keys if key in override})
+        return config
+
     def _accept(self, msg, id_):
-        if not self.config["joins"] and (msg.joined or msg.left):
+        config = self._plug_config(msg.channel if isinstance(msg, immp.Receipt) else None)
+        if not config["joins"] and (msg.joined or msg.left):
             log.debug("Not syncing join/part message: %r", id_)
             return False
-        if not self.config["renames"] and msg.title:
+        if not config["renames"] and msg.title:
             log.debug("Not syncing rename message: %r", id_)
             return False
         return True
@@ -519,6 +543,7 @@ class _SyncHookBase(immp.Hook):
                 await func(attach, *args)
 
     async def _rename_user(self, user, channel):
+        config = self._plug_config(channel)
         # Use name-format or identities to render a suitable author real name.
         base = (user.real_name or user.username) if user else None
         name = None
@@ -530,13 +555,13 @@ class _SyncHookBase(immp.Hook):
             except Exception:
                 log.warning("Failed to retrieve identity information for %r", user,
                             exc_info=True)
-        if self.config["name-format"]:
+        if config["name-format"]:
             if not Template:
                 raise immp.PlugError("'jinja2' module not installed")
             title = await channel.title() if channel else None
             context = {"user": user, "identity": identity, "channel": title}
             try:
-                name = Template(self.config["name-format"]).render(**context)
+                name = Template(config["name-format"]).render(**context)
             except TemplateError:
                 log.warning("Bad name format template", exc_info=True)
             else:
@@ -544,7 +569,7 @@ class _SyncHookBase(immp.Hook):
                 force = True
         elif identity:
             name = "{} ({})".format(base, identity.name)
-        if self.config["strip-name-emoji"]:
+        if config["strip-name-emoji"]:
             if not EMOJI_REGEX:
                 raise immp.PlugError("'emoji' module not installed")
             current = name or base
@@ -552,14 +577,14 @@ class _SyncHookBase(immp.Hook):
                 name = EMOJI_REGEX.sub(_emoji_replace, current).strip()
         if not name:
             return user
-        elif self.config["reset-author"] or not user:
+        elif config["reset-author"] or not user:
             log.debug("Creating unlinked user with real name: %r", name)
-            return immp.User(real_name=name)
+            return immp.User(real_name=name, suggested=(user.suggested if user else False))
         else:
             log.debug("Copying user with new real name: %r -> %r", user, name)
             return immp.User(id_=user.id, plug=user.plug, real_name=name,
                              username=(None if force else user.username),
-                             avatar=user.avatar, link=user.link)
+                             avatar=user.avatar, link=user.link, suggested=user.suggested)
 
     async def _alter_name(self, msg):
         channel = msg.channel if isinstance(msg, immp.Receipt) else None
@@ -589,7 +614,8 @@ class _SyncHookBase(immp.Hook):
                     segment.mention = user
                     break
             # Perform name substitution on the mention text.
-            if self.config["name-format"]:
+            config = self._plug_config(channel)
+            if config["name-format"]:
                 at = "@" if segment.text.startswith("@") else ""
                 renamed = await self._rename_user(user, channel)
                 segment.text = "{}{}".format(at, renamed.real_name)
@@ -613,11 +639,14 @@ class SyncHook(_SyncHookBase):
             Virtual plug for this sync, if configured.
     """
 
-    schema = immp.Schema({immp.Optional("joins", True): bool,
+    schema = immp.Schema({immp.Optional("edits", True): bool,
+                          immp.Optional("joins", True): bool,
                           immp.Optional("renames", True): bool,
                           immp.Optional("plug"): immp.Nullable(str),
                           immp.Optional("titles", dict): {str: str}}, _SyncHookBase.schema)
 
+    user = immp.User(real_name="Sync", suggested=True)
+
     def __init__(self, name, config, host):
         super().__init__(name, config, host)
         # Message cache, stores IDs of all synced messages by channel.
@@ -691,7 +720,7 @@ class SyncHook(_SyncHookBase):
         if missing:
             text.append(immp.Segment("\n"),
                         immp.Segment("(list may be incomplete)"))
-        await msg.channel.send(immp.Message(user=immp.User(real_name="Sync"), text=text))
+        await msg.channel.send(immp.Message(user=self.user, text=text))
 
     @command("sync-list", test=_test)
     async def list(self, msg):
@@ -704,7 +733,7 @@ class SyncHook(_SyncHookBase):
             title = await synced.title()
             if title:
                 text.append(immp.Segment(": {}".format(title)))
-        await msg.channel.send(immp.Message(user=immp.User(real_name="Sync"), text=text))
+        await msg.channel.send(immp.Message(user=self.user, text=text))
 
     async def send(self, label, msg, origin=None, ref=None, update=False):
         """
@@ -823,12 +852,19 @@ class SyncHook(_SyncHookBase):
                 log.debug("Incoming message not in sync cache: %r", sent)
         else:
             if sent.deleted:
-                log.debug("Incoming message is a delete, needs sync: %r", sent)
-                await self.delete(ref)
+                if self.config["edits"]:
+                    log.debug("Incoming message is a delete, needs sync: %r", sent)
+                    await self.delete(ref)
+                else:
+                    log.debug("Ignoring deleted message: %r", sent)
                 return
             elif (sent.edited and not ref.revisions) or ref.revision(sent):
-                log.debug("Incoming message is an update, needs sync: %r", sent)
-                update = True
+                if self.config["edits"]:
+                    log.debug("Incoming message is an update, needs sync: %r", sent)
+                    update = True
+                else:
+                    log.debug("Ignoring updated message: %r", sent)
+                    return
             elif all(ref.ids[channel] for channel in self.channels[label]):
                 log.debug("Incoming message already synced: %r", sent)
                 return
