@@ -13,7 +13,7 @@ Config:
         Whether the token represents a bot user (true by default).
     members (bool):
         Whether to use the privileged members intent to retrieve per-server member information.
-        Without this, per-server nicknames will be unavailable.
+        Without this, per-server nicknames and channel member lists will be unavailable.
 
         Before enabling here, you must enable the intent in Discord's developer site, otherwise the
         underlying client will fail to connect.  For bots in large numbers of servers, this may
@@ -323,7 +323,7 @@ class DiscordMessage(immp.Message):
         attachments = []
         if message.content:
             text = DiscordRichText.from_message(discord_, message)
-        if message.reference:
+        if message.reference and not message.flags.is_crossposted:
             receipt = immp.Receipt(message.reference.message_id,
                                    immp.Channel(discord_, message.reference.channel_id))
             reply_to = await discord_.get_message(receipt)
@@ -537,12 +537,25 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
         if isinstance(dc_channel, discord.TextChannel):
             return [DiscordUser.from_user(self, member) for member in dc_channel.members]
         elif isinstance(dc_channel, discord.GroupChannel):
-            return [DiscordUser.from_user(self, member) for member in dc_channel.recipients]
+            return ([DiscordUser.from_user(self, dc_channel.me)] +
+                    [DiscordUser.from_user(self, member) for member in dc_channel.recipients])
         elif isinstance(dc_channel, discord.DMChannel):
             return [DiscordUser.from_user(self, dc_channel.me),
                     DiscordUser.from_user(self, dc_channel.recipient)]
         else:
-            return []
+            return None
+
+    async def channel_admins(self, channel):
+        dc_channel = self._get_channel(channel)
+        if isinstance(dc_channel, discord.TextChannel):
+            members = dc_channel.members
+        elif isinstance(dc_channel, discord.GroupChannel):
+            members = [dc_channel.me] + dc_channel.recipients
+        else:
+            return None
+        perms = {user: dc_channel.permissions_for(user) for user in members}
+        return [DiscordUser.from_user(self, user) for user, perm in perms.items()
+                if perm.administrator or perm.manage_messages]
 
     async def channel_link_create(self, channel, shared=True):
         dc_channel = self._get_channel(channel)
@@ -571,6 +584,9 @@ class DiscordPlug(immp.Plug, immp.HTTPOpenable):
 
     async def get_message(self, receipt):
         dc_channel = self._get_channel(receipt.channel)
+        if dc_channel is None:
+            log.debug("Channel %r of message not available", receipt.channel)
+            return None
         message = await dc_channel.fetch_message(receipt.id)
         return await DiscordMessage.from_message(self, message)
 
